@@ -12,5 +12,8 @@ PYBIND11_MODULE(_geysercpp, m) {
             .def_property_readonly("concurrency", &geyser::Core::concurrency)
             .def("__getitem__", &geyser::Core::access)
             .def("execute", &geyser::Core::execute)
-            .def_property_readonly("compiler", &geyser::Core::compiler);
+            .def_property_readonly("compiler", &geyser::Core::compiler)
+            .def_property_readonly("class_count", &geyser::Core::class_count)
+            .def_property_readonly("object_count", &geyser::Core::object_count)
+            .def_property_readonly("references", &geyser::Core::references);
 }
\ No newline at end of file
